@@ -83,6 +83,15 @@ where
     /// RAII guard to change context temporarically
     #[inline]
     pub(super) fn with_ctx(&mut self, ctx: Ctx) -> WithCtx<'_, 'b, M> {
+        if cfg!(debug_assertions) {
+            let scope_ctxt = ctx.scope;
+            if self.ctx.scope != scope_ctxt {
+                if let Some(data) = &self.data {
+                    data.scopes.get(&scope_ctxt).expect("scope not found");
+                }
+            }
+        }
+
         let orig_ctx = self.ctx;
         self.ctx = ctx;
         WithCtx {
