@@ -9,18 +9,21 @@ use crate::{marks::Marks, option::MangleOptions, pass::compute_char_freq::CharFr
 
 pub(crate) fn name_mangler(
     options: MangleOptions,
-    _char_freq_info: CharFreqInfo,
+    char_freq_info: CharFreqInfo,
     _marks: Marks,
     top_level_ctxt: SyntaxContext,
 ) -> impl VisitMut {
     Mangler {
         options,
         top_level_ctxt,
+        char_freq_info,
     }
 }
 
 struct Mangler {
     options: MangleOptions,
+    char_freq_info: CharFreqInfo,
+
     /// Used to check `eval`.
     top_level_ctxt: SyntaxContext,
 }
@@ -54,7 +57,7 @@ impl VisitMut for Mangler {
             };
             m.visit_with(&mut analyzer);
 
-            analyzer.into_rename_map(&preserved)
+            analyzer.into_rename_map(&self.char_freq_info, &preserved)
         };
 
         m.visit_mut_with(&mut rename(&map));
@@ -74,7 +77,7 @@ impl VisitMut for Mangler {
             };
             s.visit_with(&mut analyzer);
 
-            analyzer.into_rename_map(&preserved)
+            analyzer.into_rename_map(&self.char_freq_info, &preserved)
         };
 
         s.visit_mut_with(&mut rename(&map));
